@@ -1,5 +1,5 @@
 ##
-#  Copyright (c) 2008-2013 Fred Hutchinson Cancer Research Center
+#  Copyright (c) 2008-2014 Fred Hutchinson Cancer Research Center
 # 
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -68,7 +68,7 @@ if(is.null(containerFilter)==FALSE) {myurl <- paste(myurl,"&containerFilter=",co
 ## Set options
 reader <- basicTextGatherer()
 header <- basicTextGatherer()
-myopts <- curlOptions(writefunction=reader$update, headerfunction=header$update, netrc=1, ssl.verifyhost=FALSE, ssl.verifypeer=FALSE, followlocation=TRUE)
+myopts<- curlOptions(netrc=1, writefunction=reader$update, headerfunction=header$update, .opts=c(labkey.curlOptions()))
 
 ## Support user-settable options for debuggin and setting proxies etc
 if(exists(".lksession"))
@@ -98,13 +98,13 @@ status <- getCurlInfo(handle)$response.code
 message <- h$statusMessage
 
 if(status==500)
-{decode <- fromJSON2(mydata); message <- decode$exception; stop(paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))}
+{decode <- fromJSON(mydata); message <- decode$exception; stop(paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))}
 if(status>=400)
 {
     contTypes <- which(names(h)=='Content-Type')
     if(length(contTypes)>0 && (tolower(h[contTypes[1]])=="application/json;charset=utf-8" || tolower(h[contTypes[2]])=="application/json;charset=utf-8"))
     {
-        decode <- fromJSON2(mydata);
+        decode <- fromJSON(mydata);
         message<-decode$exception;
         stop (paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))
     } else
